Class: Pipedrive::BaseMailThreadMessagesAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseMailThreadMessagesAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::BaseMailThreadMessagesAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::BaseMailThreadMessagesAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    if (value = attributes[:'from']).is_a?(Array)
      self.from = value
    end
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  end

  if attributes.key?(:'body_url')
    self.body_url = attributes[:'body_url']
  end

  if attributes.key?(:'mail_thread_id')
    self.mail_thread_id = attributes[:'mail_thread_id']
  end

  if attributes.key?(:'draft')
    self.draft = attributes[:'draft']
  end

  if attributes.key?(:'has_body_flag')
    self.has_body_flag = attributes[:'has_body_flag']
  end

  if attributes.key?(:'sent_flag')
    self.sent_flag = attributes[:'sent_flag']
  end

  if attributes.key?(:'sent_from_pipedrive_flag')
    self.sent_from_pipedrive_flag = attributes[:'sent_from_pipedrive_flag']
  end

  if attributes.key?(:'message_time')
    self.message_time = attributes[:'message_time']
  end

  if attributes.key?(:'add_time')
    self.add_time = attributes[:'add_time']
  end

  if attributes.key?(:'update_time')
    self.update_time = attributes[:'update_time']
  end
end

Instance Attribute Details

#add_timeObject

The time when the mail message was inserted to database



51
52
53
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 51

def add_time
  @add_time
end

#bccObject

Participants of the Bcc



27
28
29
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 27

def bcc
  @bcc
end

#body_urlObject

A link to the mail thread message



30
31
32
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 30

def body_url
  @body_url
end

#ccObject

Participants of the Cc



24
25
26
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 24

def cc
  @cc
end

#draftObject

If the mail message has a draft status then the value is the mail message object as JSON formatted string, otherwise null.



36
37
38
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 36

def draft
  @draft
end

#fromObject

Senders of the mail thread



18
19
20
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 18

def from
  @from
end

#has_body_flagObject

Whether the mail thread message has a body



39
40
41
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 39

def has_body_flag
  @has_body_flag
end

#mail_thread_idObject

ID of the mail thread



33
34
35
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 33

def mail_thread_id
  @mail_thread_id
end

#message_timeObject

The time when the mail message was received or created



48
49
50
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 48

def message_time
  @message_time
end

#sent_flagObject

Whether the mail thread message is sent



42
43
44
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 42

def sent_flag
  @sent_flag
end

#sent_from_pipedrive_flagObject

Whether the mail thread message is sent from Pipedrive



45
46
47
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 45

def sent_from_pipedrive_flag
  @sent_from_pipedrive_flag
end

#toObject

Recipients of the mail thread



21
22
23
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 21

def to
  @to
end

#update_timeObject

The time when the mail message was updated in database received



54
55
56
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 54

def update_time
  @update_time
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 57

def self.attribute_map
  {
    :'from' => :'from',
    :'to' => :'to',
    :'cc' => :'cc',
    :'bcc' => :'bcc',
    :'body_url' => :'body_url',
    :'mail_thread_id' => :'mail_thread_id',
    :'draft' => :'draft',
    :'has_body_flag' => :'has_body_flag',
    :'sent_flag' => :'sent_flag',
    :'sent_from_pipedrive_flag' => :'sent_from_pipedrive_flag',
    :'message_time' => :'message_time',
    :'add_time' => :'add_time',
    :'update_time' => :'update_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 225

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 95

def self.openapi_nullable
  Set.new([
    :'draft',
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 76

def self.openapi_types
  {
    :'from' => :'Array<MailThreadParticipant>',
    :'to' => :'Array<MailThreadParticipant>',
    :'cc' => :'Array<MailThreadParticipant>',
    :'bcc' => :'Array<MailThreadParticipant>',
    :'body_url' => :'String',
    :'mail_thread_id' => :'Integer',
    :'draft' => :'String',
    :'has_body_flag' => :'NumberBooleanDefault0',
    :'sent_flag' => :'NumberBooleanDefault0',
    :'sent_from_pipedrive_flag' => :'NumberBooleanDefault0',
    :'message_time' => :'DateTime',
    :'add_time' => :'DateTime',
    :'update_time' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      to == o.to &&
      cc == o.cc &&
      bcc == o.bcc &&
      body_url == o.body_url &&
      mail_thread_id == o.mail_thread_id &&
      draft == o.draft &&
      has_body_flag == o.has_body_flag &&
      sent_flag == o.sent_flag &&
      sent_from_pipedrive_flag == o.sent_from_pipedrive_flag &&
      message_time == o.message_time &&
      add_time == o.add_time &&
      update_time == o.update_time
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Pipedrive.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 322

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 232

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 218

def hash
  [from, to, cc, bcc, body_url, mail_thread_id, draft, has_body_flag, sent_flag, sent_from_pipedrive_flag, message_time, add_time, update_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 298

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



292
293
294
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 292

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages_all_of.rb', line 186

def valid?
  true
end