Class: Pipedrive::BasicDeal

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/models/basic_deal.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BasicDeal

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::BasicDeal` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::BasicDeal`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'person_id')
    self.person_id = attributes[:'person_id']
  end

  if attributes.key?(:'org_id')
    self.org_id = attributes[:'org_id']
  end

  if attributes.key?(:'stage_id')
    self.stage_id = attributes[:'stage_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'probability')
    self.probability = attributes[:'probability']
  end

  if attributes.key?(:'lost_reason')
    self.lost_reason = attributes[:'lost_reason']
  end

  if attributes.key?(:'visible_to')
    self.visible_to = attributes[:'visible_to']
  end
end

Instance Attribute Details

#currencyObject

Currency of the deal. Accepts a 3-character currency code. If omitted, currency will be set to the default currency of the authorized user.



24
25
26
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 24

def currency
  @currency
end

#lost_reasonObject

Optional message about why the deal was lost (to be used when status=lost)



45
46
47
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 45

def lost_reason
  @lost_reason
end

#org_idObject

ID of the organization this deal will be associated with



33
34
35
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 33

def org_id
  @org_id
end

#person_idObject

ID of the person this deal will be associated with



30
31
32
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 30

def person_id
  @person_id
end

#probabilityObject

Deal success probability percentage. Used/shown only when deal_probability for the pipeline of the deal is enabled.



42
43
44
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 42

def probability
  @probability
end

#stage_idObject

ID of the stage this deal will be placed in a pipeline (note that you can’t supply the ID of the pipeline as this will be assigned automatically based on stage_id). If omitted, the deal will be placed in the first stage of the default pipeline.



36
37
38
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 36

def stage_id
  @stage_id
end

#statusObject

open = Open, won = Won, lost = Lost, deleted = Deleted. If omitted, status will be set to open.



39
40
41
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 39

def status
  @status
end

#titleObject

Deal title



18
19
20
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 18

def title
  @title
end

#user_idObject

ID of the user who will be marked as the owner of this deal. If omitted, the authorized user ID will be used.



27
28
29
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 27

def user_id
  @user_id
end

#valueObject

Value of the deal. If omitted, value will be set to 0.



21
22
23
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 21

def value
  @value
end

#visible_toObject

Visibility of the deal. If omitted, visibility will be set to the default visibility setting of this item type for the authorized user.<dl class="fields-list"><dt>1</dt><dd>Owner &amp; followers (private)</dd><dt>3</dt><dd>Entire company (shared)</dd></dl>



48
49
50
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 48

def visible_to
  @visible_to
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 73

def self.attribute_map
  {
    :'title' => :'title',
    :'value' => :'value',
    :'currency' => :'currency',
    :'user_id' => :'user_id',
    :'person_id' => :'person_id',
    :'org_id' => :'org_id',
    :'stage_id' => :'stage_id',
    :'status' => :'status',
    :'probability' => :'probability',
    :'lost_reason' => :'lost_reason',
    :'visible_to' => :'visible_to'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 230

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 90

def self.openapi_types
  {
    :'title' => :'String',
    :'value' => :'String',
    :'currency' => :'String',
    :'user_id' => :'Integer',
    :'person_id' => :'Integer',
    :'org_id' => :'Integer',
    :'stage_id' => :'Integer',
    :'status' => :'String',
    :'probability' => :'Float',
    :'lost_reason' => :'String',
    :'visible_to' => :'VisibleTo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      value == o.value &&
      currency == o.currency &&
      user_id == o.user_id &&
      person_id == o.person_id &&
      org_id == o.org_id &&
      stage_id == o.stage_id &&
      status == o.status &&
      probability == o.probability &&
      lost_reason == o.lost_reason &&
      visible_to == o.visible_to
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 258

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Pipedrive.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 327

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 237

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 223

def hash
  [title, value, currency, user_id, person_id, org_id, stage_id, status, probability, lost_reason, visible_to].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 174

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 303

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



297
298
299
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 297

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
# File 'lib/pipedrive-openapi-client/models/basic_deal.rb', line 181

def valid?
  status_validator = EnumAttributeValidator.new('String', ["open", "won", "lost", "deleted"])
  return false unless status_validator.valid?(@status)
  true
end