Class: Pipedrive::DealFieldsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/api/deal_fields_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DealFieldsApi

Returns a new instance of DealFieldsApi.



19
20
21
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#deal_fields_delete(ids, opts = {}) ⇒ nil

Delete multiple deal fields in bulk Marks multiple fields as deleted.

Parameters:

  • ids (String)

    Comma-separated field IDs to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


27
28
29
30
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 27

def deal_fields_delete(ids, opts = {})
  deal_fields_delete_with_http_info(ids, opts)
  nil
end

#deal_fields_delete_with_http_info(ids, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete multiple deal fields in bulk Marks multiple fields as deleted.

Parameters:

  • ids (String)

    Comma-separated field IDs to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 37

def deal_fields_delete_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DealFieldsApi.deal_fields_delete ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling DealFieldsApi.deal_fields_delete"
  end
  # resource path
  local_var_path = '/dealFields'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = ids

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DealFieldsApi#deal_fields_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#deal_fields_get(opts = {}) ⇒ nil

Get all deal fields Returns data about all fields deals can have

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :start (Integer)

    Pagination start (default to 0)

  • :limit (Integer)

    Items shown per page

Returns:

  • (nil)


89
90
91
92
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 89

def deal_fields_get(opts = {})
  deal_fields_get_with_http_info(opts)
  nil
end

#deal_fields_get_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get all deal fields Returns data about all fields deals can have

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :start (Integer)

    Pagination start

  • :limit (Integer)

    Items shown per page

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 100

def deal_fields_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DealFieldsApi.deal_fields_get ...'
  end
  # resource path
  local_var_path = '/dealFields'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'start'] = opts[:'start'] if !opts[:'start'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DealFieldsApi#deal_fields_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#deal_fields_id_delete(id, opts = {}) ⇒ nil

Delete a deal field Marks a field as deleted. For more information on how to delete a custom field, see <a href="pipedrive.readme.io/docs/deleting-a-custom-field" target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • id (Integer)

    ID of the field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


148
149
150
151
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 148

def deal_fields_id_delete(id, opts = {})
  deal_fields_id_delete_with_http_info(id, opts)
  nil
end

#deal_fields_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a deal field Marks a field as deleted. For more information on how to delete a custom field, see &lt;a href&#x3D;&quot;pipedrive.readme.io/docs/deleting-a-custom-field&quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • id (Integer)

    ID of the field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 158

def deal_fields_id_delete_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DealFieldsApi.deal_fields_id_delete ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DealFieldsApi.deal_fields_id_delete"
  end
  # resource path
  local_var_path = '/dealFields/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DealFieldsApi#deal_fields_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#deal_fields_id_get(id, opts = {}) ⇒ nil

Get one deal field Returns data about a specific deal field.

Parameters:

  • id (Integer)

    ID of the field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


208
209
210
211
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 208

def deal_fields_id_get(id, opts = {})
  deal_fields_id_get_with_http_info(id, opts)
  nil
end

#deal_fields_id_get_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get one deal field Returns data about a specific deal field.

Parameters:

  • id (Integer)

    ID of the field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 218

def deal_fields_id_get_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DealFieldsApi.deal_fields_id_get ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DealFieldsApi.deal_fields_id_get"
  end
  # resource path
  local_var_path = '/dealFields/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DealFieldsApi#deal_fields_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#deal_fields_id_put(id, name, opts = {}) ⇒ nil

Update a deal field Updates a deal field. See an example of updating custom fields’ values in <a href=" pipedrive.readme.io/docs/updating-custom-field-value " target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • id (Integer)

    ID of the field

  • name (String)

    Name of the field

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :options (String)

    When field_type is either set or enum, possible options must be supplied as a JSON-encoded sequential array, for example: [\&quot;red\&quot;,\&quot;blue\&quot;,\&quot;lilac\&quot;]

Returns:

  • (nil)


270
271
272
273
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 270

def deal_fields_id_put(id, name, opts = {})
  deal_fields_id_put_with_http_info(id, name, opts)
  nil
end

#deal_fields_id_put_with_http_info(id, name, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update a deal field Updates a deal field. See an example of updating custom fields’ values in &lt;a href&#x3D;&quot; pipedrive.readme.io/docs/updating-custom-field-value &quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • id (Integer)

    ID of the field

  • name (String)

    Name of the field

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :options (String)

    When field_type is either set or enum, possible options must be supplied as a JSON-encoded sequential array, for example: [\&quot;red\&quot;,\&quot;blue\&quot;,\&quot;lilac\&quot;]

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 282

def deal_fields_id_put_with_http_info(id, name, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DealFieldsApi.deal_fields_id_put ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DealFieldsApi.deal_fields_id_put"
  end
  # verify the required parameter 'name' is set
  if @api_client.config.client_side_validation && name.nil?
    fail ArgumentError, "Missing the required parameter 'name' when calling DealFieldsApi.deal_fields_id_put"
  end
  # resource path
  local_var_path = '/dealFields/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/x-www-form-urlencoded'])

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['name'] = name
  form_params['options'] = opts[:'options'] if !opts[:'options'].nil?

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DealFieldsApi#deal_fields_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#deal_fields_post(opts = {}) ⇒ nil

Add a new deal field Adds a new deal field. For more information on adding a new custom field, see <a href="pipedrive.readme.io/docs/adding-a-new-custom-field" target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


339
340
341
342
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 339

def deal_fields_post(opts = {})
  deal_fields_post_with_http_info(opts)
  nil
end

#deal_fields_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Add a new deal field Adds a new deal field. For more information on adding a new custom field, see &lt;a href&#x3D;&quot;pipedrive.readme.io/docs/adding-a-new-custom-field&quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/pipedrive-openapi-client/api/deal_fields_api.rb', line 348

def deal_fields_post_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DealFieldsApi.deal_fields_post ...'
  end
  # resource path
  local_var_path = '/dealFields'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/x-www-form-urlencoded'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DealFieldsApi#deal_fields_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end