Class: Pipedrive::DealNonStrictModeFieldsCreatorUserId
- Inherits:
-
Object
- Object
- Pipedrive::DealNonStrictModeFieldsCreatorUserId
- Defined in:
- lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb
Overview
The creator of the Deal
Instance Attribute Summary collapse
-
#active_flag ⇒ Object
If the creator is activated or not.
-
#email ⇒ Object
The email of the Deal creator.
-
#has_pic ⇒ Object
If the creator has a picture or not.
-
#id ⇒ Object
The ID of the Deal creator.
-
#name ⇒ Object
The name of the Deal creator.
-
#pic_hash ⇒ Object
The creator picture hash.
-
#value ⇒ Object
The ID of the Deal creator.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DealNonStrictModeFieldsCreatorUserId
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DealNonStrictModeFieldsCreatorUserId
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::DealNonStrictModeFieldsCreatorUserId` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::DealNonStrictModeFieldsCreatorUserId`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'has_pic') self.has_pic = attributes[:'has_pic'] end if attributes.key?(:'pic_hash') self.pic_hash = attributes[:'pic_hash'] end if attributes.key?(:'active_flag') self.active_flag = attributes[:'active_flag'] end if attributes.key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#active_flag ⇒ Object
If the creator is activated or not
34 35 36 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 34 def active_flag @active_flag end |
#email ⇒ Object
The email of the Deal creator
25 26 27 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 25 def email @email end |
#has_pic ⇒ Object
If the creator has a picture or not
28 29 30 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 28 def has_pic @has_pic end |
#id ⇒ Object
The ID of the Deal creator
19 20 21 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 19 def id @id end |
#name ⇒ Object
The name of the Deal creator
22 23 24 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 22 def name @name end |
#pic_hash ⇒ Object
The creator picture hash
31 32 33 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 31 def pic_hash @pic_hash end |
#value ⇒ Object
The ID of the Deal creator
37 38 39 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 37 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 40 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'email' => :'email', :'has_pic' => :'has_pic', :'pic_hash' => :'pic_hash', :'active_flag' => :'active_flag', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 158 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 66 def self.openapi_nullable Set.new([ :'pic_hash', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 53 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'email' => :'String', :'has_pic' => :'Boolean', :'pic_hash' => :'String', :'active_flag' => :'Boolean', :'value' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && email == o.email && has_pic == o.has_pic && pic_hash == o.pic_hash && active_flag == o.active_flag && value == o.value end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 186 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Pipedrive.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 255 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 165 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 151 def hash [id, name, email, has_pic, pic_hash, active_flag, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 118 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
231 232 233 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 231 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
225 226 227 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 225 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 |
# File 'lib/pipedrive-openapi-client/models/deal_non_strict_mode_fields_creator_user_id.rb', line 125 def valid? true end |