Class: Pipedrive::GlobalMessagesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/api/global_messages_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ GlobalMessagesApi



19
20
21
# File 'lib/pipedrive-openapi-client/api/global_messages_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pipedrive-openapi-client/api/global_messages_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#global_messages_get(opts = {}) ⇒ GlobalMessageGet

Get global messages Returns data about global messages to display for the authorized user.

Options Hash (opts):

  • :limit (Integer)

    Number of messages to get from 1 to 100. The message number 1 is returned by default. (default to 1)



27
28
29
30
# File 'lib/pipedrive-openapi-client/api/global_messages_api.rb', line 27

def global_messages_get(opts = {})
  data, _status_code, _headers = global_messages_get_with_http_info(opts)
  data
end

#global_messages_get_with_http_info(opts = {}) ⇒ Array<(GlobalMessageGet, Integer, Hash)>

Get global messages Returns data about global messages to display for the authorized user.

Options Hash (opts):

  • :limit (Integer)

    Number of messages to get from 1 to 100. The message number 1 is returned by default.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pipedrive-openapi-client/api/global_messages_api.rb', line 37

def global_messages_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GlobalMessagesApi.global_messages_get ...'
  end
  # resource path
  local_var_path = '/globalMessages'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'GlobalMessageGet' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GlobalMessagesApi#global_messages_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#global_messages_id_delete(id, opts = {}) ⇒ GlobalMessageDelete

Dismiss a global message Removes global message from being shown, if message is dismissible



86
87
88
89
# File 'lib/pipedrive-openapi-client/api/global_messages_api.rb', line 86

def global_messages_id_delete(id, opts = {})
  data, _status_code, _headers = global_messages_id_delete_with_http_info(id, opts)
  data
end

#global_messages_id_delete_with_http_info(id, opts = {}) ⇒ Array<(GlobalMessageDelete, Integer, Hash)>

Dismiss a global message Removes global message from being shown, if message is dismissible



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/pipedrive-openapi-client/api/global_messages_api.rb', line 96

def global_messages_id_delete_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GlobalMessagesApi.global_messages_id_delete ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling GlobalMessagesApi.global_messages_id_delete"
  end
  # resource path
  local_var_path = '/globalMessages/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'GlobalMessageDelete' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GlobalMessagesApi#global_messages_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end