Class: Pipedrive::InlineObject10
- Inherits:
-
Object
- Object
- Pipedrive::InlineObject10
- Defined in:
- lib/pipedrive-openapi-client/models/inline_object10.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#item_id ⇒ Object
ID of the item to associate the file with.
-
#item_type ⇒ Object
The item type.
-
#remote_id ⇒ Object
The remote item id.
-
#remote_location ⇒ Object
The location type to send the file to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InlineObject10
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InlineObject10
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::InlineObject10` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::InlineObject10`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'item_type') self.item_type = attributes[:'item_type'] end if attributes.key?(:'item_id') self.item_id = attributes[:'item_id'] end if attributes.key?(:'remote_id') self.remote_id = attributes[:'remote_id'] end if attributes.key?(:'remote_location') self.remote_location = attributes[:'remote_location'] end end |
Instance Attribute Details
#item_id ⇒ Object
ID of the item to associate the file with
21 22 23 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 21 def item_id @item_id end |
#item_type ⇒ Object
The item type
18 19 20 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 18 def item_type @item_type end |
#remote_id ⇒ Object
The remote item id
24 25 26 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 24 def remote_id @remote_id end |
#remote_location ⇒ Object
The location type to send the file to. Only googledrive is supported at the moment.
27 28 29 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 27 def remote_location @remote_location end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 52 def self.attribute_map { :'item_type' => :'item_type', :'item_id' => :'item_id', :'remote_id' => :'remote_id', :'remote_location' => :'remote_location' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 192 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 62 def self.openapi_types { :'item_type' => :'String', :'item_id' => :'Integer', :'remote_id' => :'String', :'remote_location' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && item_type == o.item_type && item_id == o.item_id && remote_id == o.remote_id && remote_location == o.remote_location end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 220 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Pipedrive.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 289 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 199 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 185 def hash [item_type, item_id, remote_id, remote_location].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 111 def list_invalid_properties invalid_properties = Array.new if @item_type.nil? invalid_properties.push('invalid value for "item_type", item_type cannot be nil.') end if @item_id.nil? invalid_properties.push('invalid value for "item_id", item_id cannot be nil.') end if @remote_id.nil? invalid_properties.push('invalid value for "remote_id", remote_id cannot be nil.') end if @remote_location.nil? invalid_properties.push('invalid value for "remote_location", remote_location cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
265 266 267 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 265 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 259 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/pipedrive-openapi-client/models/inline_object10.rb', line 134 def valid? return false if @item_type.nil? item_type_validator = EnumAttributeValidator.new('String', ["deal", "organization", "person"]) return false unless item_type_validator.valid?(@item_type) return false if @item_id.nil? return false if @remote_id.nil? return false if @remote_location.nil? remote_location_validator = EnumAttributeValidator.new('String', ["googledrive"]) return false unless remote_location_validator.valid?(@remote_location) true end |