Class: Pipedrive::InlineObject15
- Inherits:
-
Object
- Object
- Pipedrive::InlineObject15
- Defined in:
- lib/pipedrive-openapi-client/models/inline_object15.rb
Instance Attribute Summary collapse
-
#expected_close_date ⇒ Object
The date of when the Deal which will be created from the Lead is expected to be closed.
-
#is_archived ⇒ Object
A flag indicating whether the Lead is archived or not.
-
#label_ids ⇒ Object
The IDs of the Lead Labels which will be associated with the Lead.
-
#note ⇒ Object
The Lead note.
-
#organization_id ⇒ Object
The ID of an Organization which this Lead will be linked to.
-
#owner_id ⇒ Object
The ID of the User which will be the owner of the created Lead.
-
#person_id ⇒ Object
The ID of a Person which this Lead will be linked to.
-
#title ⇒ Object
The name of the Lead.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InlineObject15
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InlineObject15
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::InlineObject15` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::InlineObject15`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'owner_id') self.owner_id = attributes[:'owner_id'] end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'label_ids') if (value = attributes[:'label_ids']).is_a?(Array) self.label_ids = value end end if attributes.key?(:'person_id') self.person_id = attributes[:'person_id'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'is_archived') self.is_archived = attributes[:'is_archived'] end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'expected_close_date') self.expected_close_date = attributes[:'expected_close_date'] end end |
Instance Attribute Details
#expected_close_date ⇒ Object
The date of when the Deal which will be created from the Lead is expected to be closed. In ISO 8601 format: YYYY-MM-DD.
41 42 43 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 41 def expected_close_date @expected_close_date end |
#is_archived ⇒ Object
A flag indicating whether the Lead is archived or not
36 37 38 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 36 def is_archived @is_archived end |
#label_ids ⇒ Object
The IDs of the Lead Labels which will be associated with the Lead
27 28 29 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 27 def label_ids @label_ids end |
#note ⇒ Object
The Lead note. Can contain some allowed HTML tags such as ‘<a>`, `<b>`, etc.
24 25 26 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 24 def note @note end |
#organization_id ⇒ Object
The ID of an Organization which this Lead will be linked to. If the Organization does not exist yet, it needs to be created first. A Lead always has to be linked to a Person or Organization or both.
33 34 35 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 33 def organization_id @organization_id end |
#owner_id ⇒ Object
The ID of the User which will be the owner of the created Lead. If not provided, the user making the request will be used.
21 22 23 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 21 def owner_id @owner_id end |
#person_id ⇒ Object
The ID of a Person which this Lead will be linked to. If the Person does not exist yet, it needs to be created first. A Lead always has to be linked to a Person or Organization or both.
30 31 32 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 30 def person_id @person_id end |
#title ⇒ Object
The name of the Lead
18 19 20 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 18 def title @title end |
#value ⇒ Object
Returns the value of attribute value.
38 39 40 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 38 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 44 def self.attribute_map { :'title' => :'title', :'owner_id' => :'owner_id', :'note' => :'note', :'label_ids' => :'label_ids', :'person_id' => :'person_id', :'organization_id' => :'organization_id', :'is_archived' => :'is_archived', :'value' => :'value', :'expected_close_date' => :'expected_close_date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 182 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 78 79 80 81 82 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 74 def self.openapi_nullable Set.new([ :'title', :'note', :'person_id', :'organization_id', :'expected_close_date' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 59 def self.openapi_types { :'title' => :'String', :'owner_id' => :'Integer', :'note' => :'String', :'label_ids' => :'Array<String>', :'person_id' => :'Integer', :'organization_id' => :'Integer', :'is_archived' => :'Boolean', :'value' => :'Object', :'expected_close_date' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && owner_id == o.owner_id && note == o.note && label_ids == o.label_ids && person_id == o.person_id && organization_id == o.organization_id && is_archived == o.is_archived && value == o.value && expected_close_date == o.expected_close_date end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 210 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Pipedrive.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 279 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 175 def hash [title, owner_id, note, label_ids, person_id, organization_id, is_archived, value, expected_close_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 140 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
255 256 257 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 255 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 249 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 |
# File 'lib/pipedrive-openapi-client/models/inline_object15.rb', line 147 def valid? true end |