Class: Pipedrive::InlineResponse201Data

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/models/inline_response201_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InlineResponse201Data

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::InlineResponse201Data` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::InlineResponse201Data`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'owner_id')
    self.owner_id = attributes[:'owner_id']
  end

  if attributes.key?(:'creator_id')
    self.creator_id = attributes[:'creator_id']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'label_ids')
    if (value = attributes[:'label_ids']).is_a?(Array)
      self.label_ids = value
    end
  end

  if attributes.key?(:'person_id')
    self.person_id = attributes[:'person_id']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'source_name')
    self.source_name = attributes[:'source_name']
  end

  if attributes.key?(:'is_archived')
    self.is_archived = attributes[:'is_archived']
  end

  if attributes.key?(:'was_seen')
    self.was_seen = attributes[:'was_seen']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'expected_close_date')
    self.expected_close_date = attributes[:'expected_close_date']
  end

  if attributes.key?(:'next_activity_id')
    self.next_activity_id = attributes[:'next_activity_id']
  end

  if attributes.key?(:'add_time')
    self.add_time = attributes[:'add_time']
  end

  if attributes.key?(:'update_time')
    self.update_time = attributes[:'update_time']
  end
end

Instance Attribute Details

#add_timeObject

The date and time of when the Lead was created. In ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.



59
60
61
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 59

def add_time
  @add_time
end

#creator_idObject

The ID of the User who created the Lead



27
28
29
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 27

def creator_id
  @creator_id
end

#expected_close_dateObject

The date of when the Deal which will be created from the Lead is expected to be closed. In ISO 8601 format: YYYY-MM-DD.



53
54
55
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 53

def expected_close_date
  @expected_close_date
end

#idObject

The unique ID of the Lead in the UUID format



18
19
20
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 18

def id
  @id
end

#is_archivedObject

A flag indicating whether the Lead is archived or not



45
46
47
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 45

def is_archived
  @is_archived
end

#label_idsObject

The IDs of the Lead Labels which are associated with the Lead



33
34
35
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 33

def label_ids
  @label_ids
end

#next_activity_idObject

The ID of the next activity associated with the Lead



56
57
58
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 56

def next_activity_id
  @next_activity_id
end

#noteObject

The Lead note. Can contain some allowed HTML tags.



30
31
32
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 30

def note
  @note
end

#organization_idObject

The ID of an Organization which this Lead is linked to



39
40
41
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 39

def organization_id
  @organization_id
end

#owner_idObject

The ID of the User who owns the Lead



24
25
26
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 24

def owner_id
  @owner_id
end

#person_idObject

The ID of a Person which this Lead is linked to



36
37
38
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 36

def person_id
  @person_id
end

#source_nameObject

Defines where the Lead comes from. Will be API if the Lead was created through the Public API and will be empty string if the Lead was created manually through the UI.



42
43
44
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 42

def source_name
  @source_name
end

#titleObject

The title of the Lead



21
22
23
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 21

def title
  @title
end

#update_timeObject

The date and time of when the Lead was last updated. In ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.



62
63
64
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 62

def update_time
  @update_time
end

#valueObject

Returns the value of attribute value.



50
51
52
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 50

def value
  @value
end

#was_seenObject

A flag indicating whether the Lead was seen by someone in the Pipedrive UI



48
49
50
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 48

def was_seen
  @was_seen
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'title' => :'title',
    :'owner_id' => :'owner_id',
    :'creator_id' => :'creator_id',
    :'note' => :'note',
    :'label_ids' => :'label_ids',
    :'person_id' => :'person_id',
    :'organization_id' => :'organization_id',
    :'source_name' => :'source_name',
    :'is_archived' => :'is_archived',
    :'was_seen' => :'was_seen',
    :'value' => :'value',
    :'expected_close_date' => :'expected_close_date',
    :'next_activity_id' => :'next_activity_id',
    :'add_time' => :'add_time',
    :'update_time' => :'update_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 251

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
113
114
115
116
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 109

def self.openapi_nullable
  Set.new([
    :'person_id',
    :'organization_id',
    :'expected_close_date',
    :'next_activity_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 87

def self.openapi_types
  {
    :'id' => :'String',
    :'title' => :'String',
    :'owner_id' => :'Integer',
    :'creator_id' => :'Integer',
    :'note' => :'String',
    :'label_ids' => :'Array<String>',
    :'person_id' => :'Integer',
    :'organization_id' => :'Integer',
    :'source_name' => :'String',
    :'is_archived' => :'Boolean',
    :'was_seen' => :'Boolean',
    :'value' => :'Object',
    :'expected_close_date' => :'String',
    :'next_activity_id' => :'Integer',
    :'add_time' => :'DateTime',
    :'update_time' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      title == o.title &&
      owner_id == o.owner_id &&
      creator_id == o.creator_id &&
      note == o.note &&
      label_ids == o.label_ids &&
      person_id == o.person_id &&
      organization_id == o.organization_id &&
      source_name == o.source_name &&
      is_archived == o.is_archived &&
      was_seen == o.was_seen &&
      value == o.value &&
      expected_close_date == o.expected_close_date &&
      next_activity_id == o.next_activity_id &&
      add_time == o.add_time &&
      update_time == o.update_time
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 279

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Pipedrive.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 348

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 258

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 238

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 244

def hash
  [id, title, owner_id, creator_id, note, label_ids, person_id, organization_id, source_name, is_archived, was_seen, value, expected_close_date, next_activity_id, add_time, update_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 202

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 318

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
# File 'lib/pipedrive-openapi-client/models/inline_response201_data.rb', line 209

def valid?
  true
end