Class: Pipedrive::MailMessage
- Inherits:
-
Object
- Object
- Pipedrive::MailMessage
- Defined in:
- lib/pipedrive-openapi-client/models/mail_message.rb
Instance Attribute Summary collapse
-
#data ⇒ Object
Returns the value of attribute data.
-
#service ⇒ Object
The service name of the response.
-
#status_code ⇒ Object
The email service specific status code and it is returned through the response body.
-
#status_text ⇒ Object
The status text of the response.
-
#success ⇒ Object
If the response is successful or not.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MailMessage
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::MailMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::MailMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.key?(:'status_text') self.status_text = attributes[:'status_text'] end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'data') self.data = attributes[:'data'] end end |
Instance Attribute Details
#data ⇒ Object
Returns the value of attribute data.
29 30 31 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 29 def data @data end |
#service ⇒ Object
The service name of the response.
27 28 29 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 27 def service @service end |
#status_code ⇒ Object
The email service specific status code and it is returned through the response body.
21 22 23 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 21 def status_code @status_code end |
#status_text ⇒ Object
The status text of the response.
24 25 26 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 24 def status_text @status_text end |
#success ⇒ Object
If the response is successful or not
18 19 20 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 18 def success @success end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 32 def self.attribute_map { :'success' => :'success', :'status_code' => :'statusCode', :'status_text' => :'statusText', :'service' => :'service', :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 143 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
60 61 62 63 64 65 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 60 def self.openapi_all_of [ :'MailMessageAllOf', :'MailServiceBaseResponse' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 43 def self.openapi_types { :'success' => :'Boolean', :'status_code' => :'Integer', :'status_text' => :'String', :'service' => :'AnyType', :'data' => :'MailMessageData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && status_code == o.status_code && status_text == o.status_text && service == o.service && data == o.data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 171 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Pipedrive.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 240 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
130 131 132 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 130 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 136 def hash [success, status_code, status_text, service, data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 105 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
216 217 218 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 216 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 210 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 |
# File 'lib/pipedrive-openapi-client/models/mail_message.rb', line 112 def valid? true end |