Class: Pipedrive::MailThreadsApi
- Inherits:
-
Object
- Object
- Pipedrive::MailThreadsApi
- Defined in:
- lib/pipedrive-openapi-client/api/mail_threads_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ MailThreadsApi
constructor
A new instance of MailThreadsApi.
-
#mailbox_mail_threads_get(folder, opts = {}) ⇒ MailThread
Get mail threads Returns mail threads in specified folder ordered by most recent message within.
-
#mailbox_mail_threads_get_with_http_info(folder, opts = {}) ⇒ Array<(MailThread, Integer, Hash)>
Get mail threads Returns mail threads in specified folder ordered by most recent message within.
-
#mailbox_mail_threads_id_delete(id, opts = {}) ⇒ MailThreadDelete
Delete mail thread Marks mail thread as deleted.
-
#mailbox_mail_threads_id_delete_with_http_info(id, opts = {}) ⇒ Array<(MailThreadDelete, Integer, Hash)>
Delete mail thread Marks mail thread as deleted.
-
#mailbox_mail_threads_id_get(id, opts = {}) ⇒ MailThreadOne
Get one mail thread Returns specific mail thread.
-
#mailbox_mail_threads_id_get_with_http_info(id, opts = {}) ⇒ Array<(MailThreadOne, Integer, Hash)>
Get one mail thread Returns specific mail thread.
-
#mailbox_mail_threads_id_mail_messages_get(id, opts = {}) ⇒ MailThreadMessages
Get all mail messages of mail thread Get mail messages inside specified mail thread.
-
#mailbox_mail_threads_id_mail_messages_get_with_http_info(id, opts = {}) ⇒ Array<(MailThreadMessages, Integer, Hash)>
Get all mail messages of mail thread Get mail messages inside specified mail thread.
-
#mailbox_mail_threads_id_put(id, opts = {}) ⇒ MailThreadPut
Update mail thread details Updates the properties of a mail thread.
-
#mailbox_mail_threads_id_put_with_http_info(id, opts = {}) ⇒ Array<(MailThreadPut, Integer, Hash)>
Update mail thread details Updates the properties of a mail thread.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MailThreadsApi
Returns a new instance of MailThreadsApi.
19 20 21 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#mailbox_mail_threads_get(folder, opts = {}) ⇒ MailThread
Get mail threads Returns mail threads in specified folder ordered by most recent message within.
29 30 31 32 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 29 def mailbox_mail_threads_get(folder, opts = {}) data, _status_code, _headers = mailbox_mail_threads_get_with_http_info(folder, opts) data end |
#mailbox_mail_threads_get_with_http_info(folder, opts = {}) ⇒ Array<(MailThread, Integer, Hash)>
Get mail threads Returns mail threads in specified folder ordered by most recent message within.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 41 def mailbox_mail_threads_get_with_http_info(folder, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailThreadsApi.mailbox_mail_threads_get ...' end # verify the required parameter 'folder' is set if @api_client.config.client_side_validation && folder.nil? fail ArgumentError, "Missing the required parameter 'folder' when calling MailThreadsApi.mailbox_mail_threads_get" end # verify enum value allowable_values = ["inbox", "drafts", "sent", "archive"] if @api_client.config.client_side_validation && !allowable_values.include?(folder) fail ArgumentError, "invalid value for \"folder\", must be one of #{allowable_values}" end # resource path local_var_path = '/mailbox/mailThreads' # query parameters query_params = opts[:query_params] || {} query_params[:'folder'] = folder query_params[:'start'] = opts[:'start'] if !opts[:'start'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MailThread' # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailThreadsApi#mailbox_mail_threads_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#mailbox_mail_threads_id_delete(id, opts = {}) ⇒ MailThreadDelete
Delete mail thread Marks mail thread as deleted.
101 102 103 104 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 101 def mailbox_mail_threads_id_delete(id, opts = {}) data, _status_code, _headers = mailbox_mail_threads_id_delete_with_http_info(id, opts) data end |
#mailbox_mail_threads_id_delete_with_http_info(id, opts = {}) ⇒ Array<(MailThreadDelete, Integer, Hash)>
Delete mail thread Marks mail thread as deleted.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 111 def mailbox_mail_threads_id_delete_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailThreadsApi.mailbox_mail_threads_id_delete ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling MailThreadsApi.mailbox_mail_threads_id_delete" end # resource path local_var_path = '/mailbox/mailThreads/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MailThreadDelete' # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailThreadsApi#mailbox_mail_threads_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#mailbox_mail_threads_id_get(id, opts = {}) ⇒ MailThreadOne
Get one mail thread Returns specific mail thread.
163 164 165 166 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 163 def mailbox_mail_threads_id_get(id, opts = {}) data, _status_code, _headers = mailbox_mail_threads_id_get_with_http_info(id, opts) data end |
#mailbox_mail_threads_id_get_with_http_info(id, opts = {}) ⇒ Array<(MailThreadOne, Integer, Hash)>
Get one mail thread Returns specific mail thread.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 173 def mailbox_mail_threads_id_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailThreadsApi.mailbox_mail_threads_id_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling MailThreadsApi.mailbox_mail_threads_id_get" end # resource path local_var_path = '/mailbox/mailThreads/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MailThreadOne' # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailThreadsApi#mailbox_mail_threads_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#mailbox_mail_threads_id_mail_messages_get(id, opts = {}) ⇒ MailThreadMessages
Get all mail messages of mail thread Get mail messages inside specified mail thread.
225 226 227 228 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 225 def (id, opts = {}) data, _status_code, _headers = (id, opts) data end |
#mailbox_mail_threads_id_mail_messages_get_with_http_info(id, opts = {}) ⇒ Array<(MailThreadMessages, Integer, Hash)>
Get all mail messages of mail thread Get mail messages inside specified mail thread.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 235 def (id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailThreadsApi.mailbox_mail_threads_id_mail_messages_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling MailThreadsApi.mailbox_mail_threads_id_mail_messages_get" end # resource path local_var_path = '/mailbox/mailThreads/{id}/mailMessages'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MailThreadMessages' # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailThreadsApi#mailbox_mail_threads_id_mail_messages_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#mailbox_mail_threads_id_put(id, opts = {}) ⇒ MailThreadPut
Update mail thread details Updates the properties of a mail thread.
291 292 293 294 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 291 def mailbox_mail_threads_id_put(id, opts = {}) data, _status_code, _headers = mailbox_mail_threads_id_put_with_http_info(id, opts) data end |
#mailbox_mail_threads_id_put_with_http_info(id, opts = {}) ⇒ Array<(MailThreadPut, Integer, Hash)>
Update mail thread details Updates the properties of a mail thread.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/pipedrive-openapi-client/api/mail_threads_api.rb', line 305 def mailbox_mail_threads_id_put_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailThreadsApi.mailbox_mail_threads_id_put ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling MailThreadsApi.mailbox_mail_threads_id_put" end # resource path local_var_path = '/mailbox/mailThreads/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) # form parameters form_params = opts[:form_params] || {} form_params['deal_id'] = opts[:'deal_id'] if !opts[:'deal_id'].nil? form_params['shared_flag'] = opts[:'shared_flag'] if !opts[:'shared_flag'].nil? form_params['read_flag'] = opts[:'read_flag'] if !opts[:'read_flag'].nil? form_params['archived_flag'] = opts[:'archived_flag'] if !opts[:'archived_flag'].nil? # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MailThreadPut' # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailThreadsApi#mailbox_mail_threads_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |