Class: Pipedrive::NoteFieldsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/api/note_fields_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ NoteFieldsApi

Returns a new instance of NoteFieldsApi.



19
20
21
# File 'lib/pipedrive-openapi-client/api/note_fields_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pipedrive-openapi-client/api/note_fields_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#note_fields_get(opts = {}) ⇒ nil

Get all fields for a note Return list of all fields for note

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


26
27
28
29
# File 'lib/pipedrive-openapi-client/api/note_fields_api.rb', line 26

def note_fields_get(opts = {})
  note_fields_get_with_http_info(opts)
  nil
end

#note_fields_get_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get all fields for a note Return list of all fields for note

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/pipedrive-openapi-client/api/note_fields_api.rb', line 35

def note_fields_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NoteFieldsApi.note_fields_get ...'
  end
  # resource path
  local_var_path = '/noteFields'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NoteFieldsApi#note_fields_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end