Class: Pipedrive::OrganizationRelationshipsApi
- Inherits:
-
Object
- Object
- Pipedrive::OrganizationRelationshipsApi
- Defined in:
- lib/pipedrive-openapi-client/api/organization_relationships_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ OrganizationRelationshipsApi
constructor
A new instance of OrganizationRelationshipsApi.
-
#organization_relationships_get(org_id, opts = {}) ⇒ nil
Get all relationships for organization Gets all of the relationships for a supplied organization id.
-
#organization_relationships_get_with_http_info(org_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get all relationships for organization Gets all of the relationships for a supplied organization id.
-
#organization_relationships_id_delete(id, opts = {}) ⇒ nil
Delete an organization relationship Deletes an organization relationship and returns the deleted id.
-
#organization_relationships_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an organization relationship Deletes an organization relationship and returns the deleted id.
-
#organization_relationships_id_get(id, opts = {}) ⇒ nil
Get one organization relationship Finds and returns an organization relationship from its ID.
-
#organization_relationships_id_get_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get one organization relationship Finds and returns an organization relationship from its ID.
-
#organization_relationships_id_put(id, opts = {}) ⇒ nil
Update an organization relationship Updates and returns an organization relationship.
-
#organization_relationships_id_put_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update an organization relationship Updates and returns an organization relationship.
-
#organization_relationships_post(opts = {}) ⇒ nil
Create an organization relationship Creates and returns an organization relationship.
-
#organization_relationships_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create an organization relationship Creates and returns an organization relationship.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OrganizationRelationshipsApi
Returns a new instance of OrganizationRelationshipsApi.
19 20 21 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#organization_relationships_get(org_id, opts = {}) ⇒ nil
Get all relationships for organization Gets all of the relationships for a supplied organization id.
27 28 29 30 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 27 def organization_relationships_get(org_id, opts = {}) organization_relationships_get_with_http_info(org_id, opts) nil end |
#organization_relationships_get_with_http_info(org_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get all relationships for organization Gets all of the relationships for a supplied organization id.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 37 def organization_relationships_get_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationRelationshipsApi.organization_relationships_get ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrganizationRelationshipsApi.organization_relationships_get" end # resource path local_var_path = '/organizationRelationships' # query parameters query_params = opts[:query_params] || {} query_params[:'org_id'] = org_id # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationRelationshipsApi#organization_relationships_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#organization_relationships_id_delete(id, opts = {}) ⇒ nil
Delete an organization relationship Deletes an organization relationship and returns the deleted id.
88 89 90 91 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 88 def organization_relationships_id_delete(id, opts = {}) organization_relationships_id_delete_with_http_info(id, opts) nil end |
#organization_relationships_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an organization relationship Deletes an organization relationship and returns the deleted id.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 98 def organization_relationships_id_delete_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationRelationshipsApi.organization_relationships_id_delete ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrganizationRelationshipsApi.organization_relationships_id_delete" end # resource path local_var_path = '/organizationRelationships/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationRelationshipsApi#organization_relationships_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#organization_relationships_id_get(id, opts = {}) ⇒ nil
Get one organization relationship Finds and returns an organization relationship from its ID.
149 150 151 152 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 149 def organization_relationships_id_get(id, opts = {}) organization_relationships_id_get_with_http_info(id, opts) nil end |
#organization_relationships_id_get_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get one organization relationship Finds and returns an organization relationship from its ID.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 160 def organization_relationships_id_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationRelationshipsApi.organization_relationships_id_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrganizationRelationshipsApi.organization_relationships_id_get" end # resource path local_var_path = '/organizationRelationships/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'org_id'] = opts[:'org_id'] if !opts[:'org_id'].nil? # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationRelationshipsApi#organization_relationships_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#organization_relationships_id_put(id, opts = {}) ⇒ nil
Update an organization relationship Updates and returns an organization relationship.
215 216 217 218 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 215 def organization_relationships_id_put(id, opts = {}) organization_relationships_id_put_with_http_info(id, opts) nil end |
#organization_relationships_id_put_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update an organization relationship Updates and returns an organization relationship.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 229 def organization_relationships_id_put_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationRelationshipsApi.organization_relationships_id_put ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrganizationRelationshipsApi.organization_relationships_id_put" end allowable_values = ["parent", "related"] if @api_client.config.client_side_validation && opts[:'type'] && !allowable_values.include?(opts[:'type']) fail ArgumentError, "invalid value for \"type\", must be one of #{allowable_values}" end # resource path local_var_path = '/organizationRelationships/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) # form parameters form_params = opts[:form_params] || {} form_params['org_id'] = opts[:'org_id'] if !opts[:'org_id'].nil? form_params['type'] = opts[:'type'] if !opts[:'type'].nil? form_params['rel_owner_org_id'] = opts[:'rel_owner_org_id'] if !opts[:'rel_owner_org_id'].nil? form_params['rel_linked_org_id'] = opts[:'rel_linked_org_id'] if !opts[:'rel_linked_org_id'].nil? # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationRelationshipsApi#organization_relationships_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#organization_relationships_post(opts = {}) ⇒ nil
Create an organization relationship Creates and returns an organization relationship.
288 289 290 291 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 288 def organization_relationships_post(opts = {}) organization_relationships_post_with_http_info(opts) nil end |
#organization_relationships_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create an organization relationship Creates and returns an organization relationship.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/pipedrive-openapi-client/api/organization_relationships_api.rb', line 297 def organization_relationships_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationRelationshipsApi.organization_relationships_post ...' end # resource path local_var_path = '/organizationRelationships' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationRelationshipsApi#organization_relationships_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |