Class: Pipedrive::ProductFieldsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/api/product_fields_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ProductFieldsApi

Returns a new instance of ProductFieldsApi.



19
20
21
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#product_fields_delete(ids, opts = {}) ⇒ DeleteMultipleProductFieldsResponse

Delete multiple product fields in bulk Marks multiple fields as deleted.

Parameters:

  • ids (String)

    Comma-separated field IDs to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 27

def product_fields_delete(ids, opts = {})
  data, _status_code, _headers = product_fields_delete_with_http_info(ids, opts)
  data
end

#product_fields_delete_with_http_info(ids, opts = {}) ⇒ Array<(DeleteMultipleProductFieldsResponse, Integer, Hash)>

Delete multiple product fields in bulk Marks multiple fields as deleted.

Parameters:

  • ids (String)

    Comma-separated field IDs to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 37

def product_fields_delete_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductFieldsApi.product_fields_delete ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling ProductFieldsApi.product_fields_delete"
  end
  # resource path
  local_var_path = '/productFields'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = ids

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'DeleteMultipleProductFieldsResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductFieldsApi#product_fields_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#product_fields_get(opts = {}) ⇒ GetAllProductFieldsResponse

Get all product fields Returns data about all product fields

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



89
90
91
92
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 89

def product_fields_get(opts = {})
  data, _status_code, _headers = product_fields_get_with_http_info(opts)
  data
end

#product_fields_get_with_http_info(opts = {}) ⇒ Array<(GetAllProductFieldsResponse, Integer, Hash)>

Get all product fields Returns data about all product fields

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetAllProductFieldsResponse, Integer, Hash)>)

    GetAllProductFieldsResponse data, response status code and response headers



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 98

def product_fields_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductFieldsApi.product_fields_get ...'
  end
  # resource path
  local_var_path = '/productFields'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'GetAllProductFieldsResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductFieldsApi#product_fields_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#product_fields_id_delete(id, opts = {}) ⇒ DeleteProductFieldResponse

Delete a product field Marks a field as deleted. For more information on how to delete a custom field, see <a href="pipedrive.readme.io/docs/deleting-a-custom-field" target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • id (Integer)

    ID of the Product Field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



146
147
148
149
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 146

def product_fields_id_delete(id, opts = {})
  data, _status_code, _headers = product_fields_id_delete_with_http_info(id, opts)
  data
end

#product_fields_id_delete_with_http_info(id, opts = {}) ⇒ Array<(DeleteProductFieldResponse, Integer, Hash)>

Delete a product field Marks a field as deleted. For more information on how to delete a custom field, see &lt;a href&#x3D;&quot;pipedrive.readme.io/docs/deleting-a-custom-field&quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • id (Integer)

    ID of the Product Field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DeleteProductFieldResponse, Integer, Hash)>)

    DeleteProductFieldResponse data, response status code and response headers



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 156

def product_fields_id_delete_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductFieldsApi.product_fields_id_delete ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ProductFieldsApi.product_fields_id_delete"
  end
  # resource path
  local_var_path = '/productFields/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'DeleteProductFieldResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductFieldsApi#product_fields_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#product_fields_id_get(id, opts = {}) ⇒ GetProductFieldResponse

Get one product field Returns data about a specific product field.

Parameters:

  • id (Integer)

    ID of the Product Field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



208
209
210
211
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 208

def product_fields_id_get(id, opts = {})
  data, _status_code, _headers = product_fields_id_get_with_http_info(id, opts)
  data
end

#product_fields_id_get_with_http_info(id, opts = {}) ⇒ Array<(GetProductFieldResponse, Integer, Hash)>

Get one product field Returns data about a specific product field.

Parameters:

  • id (Integer)

    ID of the Product Field

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetProductFieldResponse, Integer, Hash)>)

    GetProductFieldResponse data, response status code and response headers



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 218

def product_fields_id_get_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductFieldsApi.product_fields_id_get ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ProductFieldsApi.product_fields_id_get"
  end
  # resource path
  local_var_path = '/productFields/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'GetProductFieldResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductFieldsApi#product_fields_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#product_fields_id_put(id, opts = {}) ⇒ GetProductFieldResponse

Update a product field Updates a product field. See an example of updating custom fields’ values in <a href=" pipedrive.readme.io/docs/updating-custom-field-value " target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • id (Integer)

    ID of the Product Field

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



271
272
273
274
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 271

def product_fields_id_put(id, opts = {})
  data, _status_code, _headers = product_fields_id_put_with_http_info(id, opts)
  data
end

#product_fields_id_put_with_http_info(id, opts = {}) ⇒ Array<(GetProductFieldResponse, Integer, Hash)>

Update a product field Updates a product field. See an example of updating custom fields’ values in &lt;a href&#x3D;&quot; pipedrive.readme.io/docs/updating-custom-field-value &quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • id (Integer)

    ID of the Product Field

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(GetProductFieldResponse, Integer, Hash)>)

    GetProductFieldResponse data, response status code and response headers



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 282

def product_fields_id_put_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductFieldsApi.product_fields_id_put ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ProductFieldsApi.product_fields_id_put"
  end
  # resource path
  local_var_path = '/productFields/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(opts[:'basic_product_field']) 

  # return_type
  return_type = opts[:return_type] || 'GetProductFieldResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductFieldsApi#product_fields_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#product_fields_post(opts = {}) ⇒ GetProductFieldResponse

Add a new product field Adds a new product field. For more information on adding a new custom field, see <a href="pipedrive.readme.io/docs/adding-a-new-custom-field" target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



336
337
338
339
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 336

def product_fields_post(opts = {})
  data, _status_code, _headers = product_fields_post_with_http_info(opts)
  data
end

#product_fields_post_with_http_info(opts = {}) ⇒ Array<(GetProductFieldResponse, Integer, Hash)>

Add a new product field Adds a new product field. For more information on adding a new custom field, see &lt;a href&#x3D;&quot;pipedrive.readme.io/docs/adding-a-new-custom-field&quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(GetProductFieldResponse, Integer, Hash)>)

    GetProductFieldResponse data, response status code and response headers



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/pipedrive-openapi-client/api/product_fields_api.rb', line 346

def product_fields_post_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductFieldsApi.product_fields_post ...'
  end
  # resource path
  local_var_path = '/productFields'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(opts[:'new_product_field']) 

  # return_type
  return_type = opts[:return_type] || 'GetProductFieldResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductFieldsApi#product_fields_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end