Class: Pipedrive::RoleSettings

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/models/role_settings.rb

Overview

The settings for the Role

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RoleSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::RoleSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::RoleSettings`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'deal_default_visibility')
    self.deal_default_visibility = attributes[:'deal_default_visibility']
  end

  if attributes.key?(:'org_default_visibility')
    self.org_default_visibility = attributes[:'org_default_visibility']
  end

  if attributes.key?(:'person_default_visibility')
    self.person_default_visibility = attributes[:'person_default_visibility']
  end

  if attributes.key?(:'product_default_visibility')
    self.product_default_visibility = attributes[:'product_default_visibility']
  end

  if attributes.key?(:'deal_access_level')
    self.deal_access_level = attributes[:'deal_access_level']
  end

  if attributes.key?(:'org_access_level')
    self.org_access_level = attributes[:'org_access_level']
  end

  if attributes.key?(:'person_access_level')
    self.person_access_level = attributes[:'person_access_level']
  end

  if attributes.key?(:'product_access_level')
    self.product_access_level = attributes[:'product_access_level']
  end
end

Instance Attribute Details

#deal_access_levelObject

The access level of the Deals for the Role (only for default Role)



31
32
33
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 31

def deal_access_level
  @deal_access_level
end

#deal_default_visibilityObject

The default visibility level of the Deals for the Role



19
20
21
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 19

def deal_default_visibility
  @deal_default_visibility
end

#org_access_levelObject

The access level of the Organizations for the Role (only for default Role)



34
35
36
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 34

def org_access_level
  @org_access_level
end

#org_default_visibilityObject

The default visibility level of the Organizations for the Role



22
23
24
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 22

def org_default_visibility
  @org_default_visibility
end

#person_access_levelObject

The access level of the People for the Role (only for default Role)



37
38
39
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 37

def person_access_level
  @person_access_level
end

#person_default_visibilityObject

The default visibility level of the People for the Role



25
26
27
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 25

def person_default_visibility
  @person_default_visibility
end

#product_access_levelObject

The access level of the Products for the Role (only for default Role)



40
41
42
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 40

def product_access_level
  @product_access_level
end

#product_default_visibilityObject

The default visibility level of the Products for the Role



28
29
30
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 28

def product_default_visibility
  @product_default_visibility
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 43

def self.attribute_map
  {
    :'deal_default_visibility' => :'deal_default_visibility',
    :'org_default_visibility' => :'org_default_visibility',
    :'person_default_visibility' => :'person_default_visibility',
    :'product_default_visibility' => :'product_default_visibility',
    :'deal_access_level' => :'deal_access_level',
    :'org_access_level' => :'org_access_level',
    :'person_access_level' => :'person_access_level',
    :'product_access_level' => :'product_access_level'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 167

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 57

def self.openapi_types
  {
    :'deal_default_visibility' => :'Float',
    :'org_default_visibility' => :'Float',
    :'person_default_visibility' => :'Float',
    :'product_default_visibility' => :'Float',
    :'deal_access_level' => :'Float',
    :'org_access_level' => :'Float',
    :'person_access_level' => :'Float',
    :'product_access_level' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      deal_default_visibility == o.deal_default_visibility &&
      org_default_visibility == o.org_default_visibility &&
      person_default_visibility == o.person_default_visibility &&
      product_default_visibility == o.product_default_visibility &&
      deal_access_level == o.deal_access_level &&
      org_access_level == o.org_access_level &&
      person_access_level == o.person_access_level &&
      product_access_level == o.product_access_level
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 195

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Pipedrive.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 264

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 174

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 160

def hash
  [deal_default_visibility, org_default_visibility, person_default_visibility, product_default_visibility, deal_access_level, org_access_level, person_access_level, product_access_level].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 126

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 240

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



234
235
236
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 234

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
# File 'lib/pipedrive-openapi-client/models/role_settings.rb', line 133

def valid?
  true
end