Class: Pipedrive::UserConnectionsApi
- Inherits:
-
Object
- Object
- Pipedrive::UserConnectionsApi
- Defined in:
- lib/pipedrive-openapi-client/api/user_connections_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ UserConnectionsApi
constructor
A new instance of UserConnectionsApi.
-
#user_connections_get(opts = {}) ⇒ UserConnections
Get all user connections Returns data about all connections for authorized user.
-
#user_connections_get_with_http_info(opts = {}) ⇒ Array<(UserConnections, Integer, Hash)>
Get all user connections Returns data about all connections for authorized user.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UserConnectionsApi
Returns a new instance of UserConnectionsApi.
19 20 21 |
# File 'lib/pipedrive-openapi-client/api/user_connections_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pipedrive-openapi-client/api/user_connections_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#user_connections_get(opts = {}) ⇒ UserConnections
Get all user connections Returns data about all connections for authorized user.
26 27 28 29 |
# File 'lib/pipedrive-openapi-client/api/user_connections_api.rb', line 26 def user_connections_get(opts = {}) data, _status_code, _headers = user_connections_get_with_http_info(opts) data end |
#user_connections_get_with_http_info(opts = {}) ⇒ Array<(UserConnections, Integer, Hash)>
Get all user connections Returns data about all connections for authorized user.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/pipedrive-openapi-client/api/user_connections_api.rb', line 35 def user_connections_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserConnectionsApi.user_connections_get ...' end # resource path local_var_path = '/userConnections' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'UserConnections' # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserConnectionsApi#user_connections_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |