Class: Pipedrive::BaseMailThreadMessages

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseMailThreadMessages

Initializes the object



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 187

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::BaseMailThreadMessages` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::BaseMailThreadMessages`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'snippet')
    self.snippet = attributes[:'snippet']
  end

  if attributes.key?(:'read_flag')
    self.read_flag = attributes[:'read_flag']
  end

  if attributes.key?(:'mail_tracking_status')
    self.mail_tracking_status = attributes[:'mail_tracking_status']
  end

  if attributes.key?(:'has_attachments_flag')
    self.has_attachments_flag = attributes[:'has_attachments_flag']
  end

  if attributes.key?(:'has_inline_attachments_flag')
    self.has_inline_attachments_flag = attributes[:'has_inline_attachments_flag']
  end

  if attributes.key?(:'has_real_attachments_flag')
    self.has_real_attachments_flag = attributes[:'has_real_attachments_flag']
  end

  if attributes.key?(:'deleted_flag')
    self.deleted_flag = attributes[:'deleted_flag']
  end

  if attributes.key?(:'synced_flag')
    self.synced_flag = attributes[:'synced_flag']
  end

  if attributes.key?(:'smart_bcc_flag')
    self.smart_bcc_flag = attributes[:'smart_bcc_flag']
  end

  if attributes.key?(:'mail_link_tracking_enabled_flag')
    self.mail_link_tracking_enabled_flag = attributes[:'mail_link_tracking_enabled_flag']
  end

  if attributes.key?(:'write_flag')
    self.write_flag = attributes[:'write_flag']
  end

  if attributes.key?(:'from')
    if (value = attributes[:'from']).is_a?(Array)
      self.from = value
    end
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  end

  if attributes.key?(:'body_url')
    self.body_url = attributes[:'body_url']
  end

  if attributes.key?(:'mail_thread_id')
    self.mail_thread_id = attributes[:'mail_thread_id']
  end

  if attributes.key?(:'draft')
    self.draft = attributes[:'draft']
  end

  if attributes.key?(:'has_body_flag')
    self.has_body_flag = attributes[:'has_body_flag']
  end

  if attributes.key?(:'sent_flag')
    self.sent_flag = attributes[:'sent_flag']
  end

  if attributes.key?(:'sent_from_pipedrive_flag')
    self.sent_from_pipedrive_flag = attributes[:'sent_from_pipedrive_flag']
  end

  if attributes.key?(:'message_time')
    self.message_time = attributes[:'message_time']
  end

  if attributes.key?(:'add_time')
    self.add_time = attributes[:'add_time']
  end

  if attributes.key?(:'update_time')
    self.update_time = attributes[:'update_time']
  end
end

Instance Attribute Details

#account_idObject

The connection account ID



21
22
23
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 21

def 
  @account_id
end

#add_timeObject

The time when the mail message was inserted to database



96
97
98
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 96

def add_time
  @add_time
end

#bccObject

Participants of the Bcc



72
73
74
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 72

def bcc
  @bcc
end

#body_urlObject

A link to the mail thread message



75
76
77
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 75

def body_url
  @body_url
end

#ccObject

Participants of the Cc



69
70
71
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 69

def cc
  @cc
end

#deleted_flagObject

Whether the mail thread is deleted



48
49
50
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 48

def deleted_flag
  @deleted_flag
end

#draftObject

If the mail message has a draft status then the value is the mail message object as JSON formatted string, otherwise null.



81
82
83
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 81

def draft
  @draft
end

#fromObject

Senders of the mail thread



63
64
65
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 63

def from
  @from
end

#has_attachments_flagObject

Whether the mail thread has an attachment



39
40
41
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 39

def has_attachments_flag
  @has_attachments_flag
end

#has_body_flagObject

Whether the mail thread message has a body



84
85
86
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 84

def has_body_flag
  @has_body_flag
end

#has_inline_attachments_flagObject

Whether the mail thread has inline attachments



42
43
44
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 42

def has_inline_attachments_flag
  @has_inline_attachments_flag
end

#has_real_attachments_flagObject

Whether the mail thread has real attachments (which are not inline)



45
46
47
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 45

def has_real_attachments_flag
  @has_real_attachments_flag
end

#idObject

ID of the mail thread



18
19
20
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 18

def id
  @id
end

Whether the link tracking of the mail thread is enabled



57
58
59
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 57

def mail_link_tracking_enabled_flag
  @mail_link_tracking_enabled_flag
end

#mail_thread_idObject

ID of the mail thread



78
79
80
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 78

def mail_thread_id
  @mail_thread_id
end

#mail_tracking_statusObject

Mail tracking status



36
37
38
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 36

def mail_tracking_status
  @mail_tracking_status
end

#message_timeObject

The time when the mail message was received or created



93
94
95
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 93

def message_time
  @message_time
end

#read_flagObject

Whether the mail thread is read



33
34
35
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 33

def read_flag
  @read_flag
end

#sent_flagObject

Whether the mail thread message is sent



87
88
89
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 87

def sent_flag
  @sent_flag
end

#sent_from_pipedrive_flagObject

Whether the mail thread message is sent from Pipedrive



90
91
92
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 90

def sent_from_pipedrive_flag
  @sent_from_pipedrive_flag
end

#smart_bcc_flagObject

Whether one of the parties of the mail thread is Bcc



54
55
56
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 54

def smart_bcc_flag
  @smart_bcc_flag
end

#snippetObject

A snippet



30
31
32
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 30

def snippet
  @snippet
end

#subjectObject

The subject



27
28
29
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 27

def subject
  @subject
end

#synced_flagObject

Whether the mail thread is synced



51
52
53
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 51

def synced_flag
  @synced_flag
end

#toObject

Recipients of the mail thread



66
67
68
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 66

def to
  @to
end

#update_timeObject

The time when the mail message was updated in database received



99
100
101
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 99

def update_time
  @update_time
end

#user_idObject

ID of the user whom mail message will be assigned to



24
25
26
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 24

def user_id
  @user_id
end

#write_flagObject

We strongly advise you to avoid the use of this property. We will soon deprecate this property



60
61
62
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 60

def write_flag
  @write_flag
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 102

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'account_id',
    :'user_id' => :'user_id',
    :'subject' => :'subject',
    :'snippet' => :'snippet',
    :'read_flag' => :'read_flag',
    :'mail_tracking_status' => :'mail_tracking_status',
    :'has_attachments_flag' => :'has_attachments_flag',
    :'has_inline_attachments_flag' => :'has_inline_attachments_flag',
    :'has_real_attachments_flag' => :'has_real_attachments_flag',
    :'deleted_flag' => :'deleted_flag',
    :'synced_flag' => :'synced_flag',
    :'smart_bcc_flag' => :'smart_bcc_flag',
    :'mail_link_tracking_enabled_flag' => :'mail_link_tracking_enabled_flag',
    :'write_flag' => :'write_flag',
    :'from' => :'from',
    :'to' => :'to',
    :'cc' => :'cc',
    :'bcc' => :'bcc',
    :'body_url' => :'body_url',
    :'mail_thread_id' => :'mail_thread_id',
    :'draft' => :'draft',
    :'has_body_flag' => :'has_body_flag',
    :'sent_flag' => :'sent_flag',
    :'sent_from_pipedrive_flag' => :'sent_from_pipedrive_flag',
    :'message_time' => :'message_time',
    :'add_time' => :'add_time',
    :'update_time' => :'update_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



384
385
386
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 384

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



178
179
180
181
182
183
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 178

def self.openapi_all_of
  [
  :'BaseMailThreadMessagesAllOf',
  :'CommonMailThread'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



170
171
172
173
174
175
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 170

def self.openapi_nullable
  Set.new([
    :'mail_tracking_status',
    :'draft',
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 136

def self.openapi_types
  {
    :'id' => :'Integer',
    :'account_id' => :'String',
    :'user_id' => :'Integer',
    :'subject' => :'String',
    :'snippet' => :'String',
    :'read_flag' => :'NumberBooleanDefault0',
    :'mail_tracking_status' => :'String',
    :'has_attachments_flag' => :'NumberBooleanDefault0',
    :'has_inline_attachments_flag' => :'NumberBooleanDefault0',
    :'has_real_attachments_flag' => :'NumberBooleanDefault0',
    :'deleted_flag' => :'NumberBooleanDefault0',
    :'synced_flag' => :'NumberBooleanDefault0',
    :'smart_bcc_flag' => :'NumberBooleanDefault0',
    :'mail_link_tracking_enabled_flag' => :'NumberBooleanDefault0',
    :'write_flag' => :'Boolean',
    :'from' => :'Array<MailThreadParticipant>',
    :'to' => :'Array<MailThreadParticipant>',
    :'cc' => :'Array<MailThreadParticipant>',
    :'bcc' => :'Array<MailThreadParticipant>',
    :'body_url' => :'String',
    :'mail_thread_id' => :'Integer',
    :'draft' => :'String',
    :'has_body_flag' => :'NumberBooleanDefault0',
    :'sent_flag' => :'NumberBooleanDefault0',
    :'sent_from_pipedrive_flag' => :'NumberBooleanDefault0',
    :'message_time' => :'DateTime',
    :'add_time' => :'DateTime',
    :'update_time' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 336

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      user_id == o.user_id &&
      subject == o.subject &&
      snippet == o.snippet &&
      read_flag == o.read_flag &&
      mail_tracking_status == o.mail_tracking_status &&
      has_attachments_flag == o.has_attachments_flag &&
      has_inline_attachments_flag == o.has_inline_attachments_flag &&
      has_real_attachments_flag == o.has_real_attachments_flag &&
      deleted_flag == o.deleted_flag &&
      synced_flag == o.synced_flag &&
      smart_bcc_flag == o.smart_bcc_flag &&
      mail_link_tracking_enabled_flag == o.mail_link_tracking_enabled_flag &&
      write_flag == o.write_flag &&
      from == o.from &&
      to == o.to &&
      cc == o.cc &&
      bcc == o.bcc &&
      body_url == o.body_url &&
      mail_thread_id == o.mail_thread_id &&
      draft == o.draft &&
      has_body_flag == o.has_body_flag &&
      sent_flag == o.sent_flag &&
      sent_from_pipedrive_flag == o.sent_from_pipedrive_flag &&
      message_time == o.message_time &&
      add_time == o.add_time &&
      update_time == o.update_time
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 412

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Pipedrive.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 481

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 391

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


371
372
373
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 371

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



377
378
379
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 377

def hash
  [id, , user_id, subject, snippet, read_flag, mail_tracking_status, has_attachments_flag, has_inline_attachments_flag, has_real_attachments_flag, deleted_flag, synced_flag, smart_bcc_flag, mail_link_tracking_enabled_flag, write_flag, from, to, cc, bcc, body_url, mail_thread_id, draft, has_body_flag, sent_flag, sent_from_pipedrive_flag, message_time, add_time, update_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



323
324
325
326
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 323

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



457
458
459
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 457

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 463

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



451
452
453
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 451

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



330
331
332
# File 'lib/pipedrive-openapi-client/models/base_mail_thread_messages.rb', line 330

def valid?
  true
end