Class: Pipedrive::FiltersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pipedrive-openapi-client/api/filters_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ FiltersApi

Returns a new instance of FiltersApi.



19
20
21
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#filters_delete(ids, opts = {}) ⇒ BaseResponse

Delete multiple filters in bulk Marks multiple filters as deleted.

Parameters:

  • ids (String)

    Comma-separated filter IDs to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 27

def filters_delete(ids, opts = {})
  data, _status_code, _headers = filters_delete_with_http_info(ids, opts)
  data
end

#filters_delete_with_http_info(ids, opts = {}) ⇒ Array<(BaseResponse, Integer, Hash)>

Delete multiple filters in bulk Marks multiple filters as deleted.

Parameters:

  • ids (String)

    Comma-separated filter IDs to delete

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BaseResponse, Integer, Hash)>)

    BaseResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 37

def filters_delete_with_http_info(ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_delete ...'
  end
  # verify the required parameter 'ids' is set
  if @api_client.config.client_side_validation && ids.nil?
    fail ArgumentError, "Missing the required parameter 'ids' when calling FiltersApi.filters_delete"
  end
  # resource path
  local_var_path = '/filters'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'ids'] = ids

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'BaseResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#filters_get(opts = {}) ⇒ BaseResponse

Get all filters Returns data about all filters.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (FilterType)

    The types of filters to fetch

Returns:



90
91
92
93
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 90

def filters_get(opts = {})
  data, _status_code, _headers = filters_get_with_http_info(opts)
  data
end

#filters_get_with_http_info(opts = {}) ⇒ Array<(BaseResponse, Integer, Hash)>

Get all filters Returns data about all filters.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (FilterType)

    The types of filters to fetch

Returns:

  • (Array<(BaseResponse, Integer, Hash)>)

    BaseResponse data, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 100

def filters_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_get ...'
  end
  # resource path
  local_var_path = '/filters'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'BaseResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#filters_helpers_get(opts = {}) ⇒ Object

Get all filter helpers Returns all supported filter helpers. It helps to know what conditions and helpers are available when you want to <a href="/docs/api/v1/#!/Filters/post_filters">add</a> or <a href="/docs/api/v1/#!/Filters/put_filters_id">update</a> filters. For more information on how filter’s helpers can be used, see <a href="pipedrive.readme.io/docs/adding-a-filter" target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


148
149
150
151
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 148

def filters_helpers_get(opts = {})
  data, _status_code, _headers = filters_helpers_get_with_http_info(opts)
  data
end

#filters_helpers_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>

Get all filter helpers Returns all supported filter helpers. It helps to know what conditions and helpers are available when you want to &lt;a href&#x3D;&quot;/docs/api/v1/#!/Filters/post_filters&quot;&gt;add&lt;/a&gt; or &lt;a href&#x3D;&quot;/docs/api/v1/#!/Filters/put_filters_id&quot;&gt;update&lt;/a&gt; filters. For more information on how filter’s helpers can be used, see &lt;a href&#x3D;&quot;pipedrive.readme.io/docs/adding-a-filter&quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 157

def filters_helpers_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_helpers_get ...'
  end
  # resource path
  local_var_path = '/filters/helpers'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'Object' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_helpers_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#filters_id_delete(opts = {}) ⇒ BaseResponse

Delete a filter Marks a filter as deleted.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



204
205
206
207
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 204

def filters_id_delete(opts = {})
  data, _status_code, _headers = filters_id_delete_with_http_info(opts)
  data
end

#filters_id_delete_with_http_info(opts = {}) ⇒ Array<(BaseResponse, Integer, Hash)>

Delete a filter Marks a filter as deleted.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BaseResponse, Integer, Hash)>)

    BaseResponse data, response status code and response headers



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 213

def filters_id_delete_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_id_delete ...'
  end
  # resource path
  local_var_path = '/filters/{id}'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'BaseResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#filters_id_get(id, opts = {}) ⇒ BaseResponse

Get one filter Returns data about a specific filter. Note that this also returns the condition lines of the filter.

Parameters:

  • id (Integer)

    The ID of the filter

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



261
262
263
264
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 261

def filters_id_get(id, opts = {})
  data, _status_code, _headers = filters_id_get_with_http_info(id, opts)
  data
end

#filters_id_get_with_http_info(id, opts = {}) ⇒ Array<(BaseResponse, Integer, Hash)>

Get one filter Returns data about a specific filter. Note that this also returns the condition lines of the filter.

Parameters:

  • id (Integer)

    The ID of the filter

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BaseResponse, Integer, Hash)>)

    BaseResponse data, response status code and response headers



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 271

def filters_id_get_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_id_get ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling FiltersApi.filters_id_get"
  end
  # resource path
  local_var_path = '/filters/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'BaseResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#filters_id_put(opts = {}) ⇒ nil

Update filter Updates an existing filter.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (nil)


323
324
325
326
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 323

def filters_id_put(opts = {})
  filters_id_put_with_http_info(opts)
  nil
end

#filters_id_put_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update filter Updates an existing filter.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 333

def filters_id_put_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_id_put ...'
  end
  # resource path
  local_var_path = '/filters/{id}'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(opts[:'inline_object13']) 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#filters_post(opts = {}) ⇒ BaseResponse

Add a new filter Adds a new filter, returns the ID upon success. Note that in the conditions JSON object only one first-level condition group is supported, and it must be glued with ‘AND’, and only two second level condition groups are supported of which one must be glued with ‘AND’ and the second with ‘OR’. Other combinations do not work (yet) but the syntax supports introducing them in future. For more information on how to add a new filter, see <a href="pipedrive.readme.io/docs/adding-a-filter" target="_blank" rel="noopener noreferrer">this tutorial</a>.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



381
382
383
384
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 381

def filters_post(opts = {})
  data, _status_code, _headers = filters_post_with_http_info(opts)
  data
end

#filters_post_with_http_info(opts = {}) ⇒ Array<(BaseResponse, Integer, Hash)>

Add a new filter Adds a new filter, returns the ID upon success. Note that in the conditions JSON object only one first-level condition group is supported, and it must be glued with &#39;AND&#39;, and only two second level condition groups are supported of which one must be glued with &#39;AND&#39; and the second with &#39;OR&#39;. Other combinations do not work (yet) but the syntax supports introducing them in future. For more information on how to add a new filter, see &lt;a href&#x3D;&quot;pipedrive.readme.io/docs/adding-a-filter&quot; target&#x3D;&quot;_blank&quot; rel&#x3D;&quot;noopener noreferrer&quot;&gt;this tutorial&lt;/a&gt;.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(BaseResponse, Integer, Hash)>)

    BaseResponse data, response status code and response headers



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/pipedrive-openapi-client/api/filters_api.rb', line 391

def filters_post_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: FiltersApi.filters_post ...'
  end
  # resource path
  local_var_path = '/filters'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(opts[:'inline_object12']) 

  # return_type
  return_type = opts[:return_type] || 'BaseResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['api_key', 'oauth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: FiltersApi#filters_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end