Class: Pipedrive::ProductAttachementFields
- Inherits:
-
Object
- Object
- Pipedrive::ProductAttachementFields
- Defined in:
- lib/pipedrive-openapi-client/models/product_attachement_fields.rb
Instance Attribute Summary collapse
-
#active_flag ⇒ Object
Boolean indicates if the Product is activated or not.
-
#add_time ⇒ Object
The date and time when the Product was added to the Deal.
-
#company_id ⇒ Object
The ID of the Company.
-
#currency ⇒ Object
The currency associated with the Deal Product.
-
#deal_id ⇒ Object
The ID of the Deal.
-
#duration_unit ⇒ Object
The type of the duration.
-
#id ⇒ Object
The ID of the deal-product (the ID of the Product attached to the Deal).
-
#last_edit ⇒ Object
The date and time when the Deal Product was last edited.
-
#name ⇒ Object
The Product name.
-
#product_id ⇒ Object
The ID of the Product.
-
#sum ⇒ Object
The sum of all the Products attached to the Deal.
-
#sum_no_discount ⇒ Object
The Product sum without the discount.
-
#tax ⇒ Object
The Product tax.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProductAttachementFields
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ProductAttachementFields
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pipedrive::ProductAttachementFields` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pipedrive::ProductAttachementFields`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] end if attributes.key?(:'deal_id') self.deal_id = attributes[:'deal_id'] end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] end if attributes.key?(:'duration_unit') self.duration_unit = attributes[:'duration_unit'] end if attributes.key?(:'sum_no_discount') self.sum_no_discount = attributes[:'sum_no_discount'] end if attributes.key?(:'sum') self.sum = attributes[:'sum'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'add_time') self.add_time = attributes[:'add_time'] end if attributes.key?(:'last_edit') self.last_edit = attributes[:'last_edit'] end if attributes.key?(:'active_flag') self.active_flag = attributes[:'active_flag'] end if attributes.key?(:'tax') self.tax = attributes[:'tax'] end if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#active_flag ⇒ Object
Boolean indicates if the Product is activated or not
48 49 50 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 48 def active_flag @active_flag end |
#add_time ⇒ Object
The date and time when the Product was added to the Deal
42 43 44 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 42 def add_time @add_time end |
#company_id ⇒ Object
The ID of the Company
21 22 23 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 21 def company_id @company_id end |
#currency ⇒ Object
The currency associated with the Deal Product
39 40 41 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 39 def currency @currency end |
#deal_id ⇒ Object
The ID of the Deal
24 25 26 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 24 def deal_id @deal_id end |
#duration_unit ⇒ Object
The type of the duration. (For example hourly, daily, etc.)
30 31 32 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 30 def duration_unit @duration_unit end |
#id ⇒ Object
The ID of the deal-product (the ID of the Product attached to the Deal)
18 19 20 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 18 def id @id end |
#last_edit ⇒ Object
The date and time when the Deal Product was last edited
45 46 47 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 45 def last_edit @last_edit end |
#name ⇒ Object
The Product name
54 55 56 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 54 def name @name end |
#product_id ⇒ Object
The ID of the Product
27 28 29 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 27 def product_id @product_id end |
#sum ⇒ Object
The sum of all the Products attached to the Deal
36 37 38 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 36 def sum @sum end |
#sum_no_discount ⇒ Object
The Product sum without the discount
33 34 35 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 33 def sum_no_discount @sum_no_discount end |
#tax ⇒ Object
The Product tax
51 52 53 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 51 def tax @tax end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 57 def self.attribute_map { :'id' => :'id', :'company_id' => :'company_id', :'deal_id' => :'deal_id', :'product_id' => :'product_id', :'duration_unit' => :'duration_unit', :'sum_no_discount' => :'sum_no_discount', :'sum' => :'sum', :'currency' => :'currency', :'add_time' => :'add_time', :'last_edit' => :'last_edit', :'active_flag' => :'active_flag', :'tax' => :'tax', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 216 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 76 def self.openapi_types { :'id' => :'Integer', :'company_id' => :'Integer', :'deal_id' => :'Integer', :'product_id' => :'Integer', :'duration_unit' => :'String', :'sum_no_discount' => :'Float', :'sum' => :'Float', :'currency' => :'String', :'add_time' => :'String', :'last_edit' => :'String', :'active_flag' => :'Boolean', :'tax' => :'Float', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && company_id == o.company_id && deal_id == o.deal_id && product_id == o.product_id && duration_unit == o.duration_unit && sum_no_discount == o.sum_no_discount && sum == o.sum && currency == o.currency && add_time == o.add_time && last_edit == o.last_edit && active_flag == o.active_flag && tax == o.tax && name == o.name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 244 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Pipedrive.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 313 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
203 204 205 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 203 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 209 def hash [id, company_id, deal_id, product_id, duration_unit, sum_no_discount, sum, currency, add_time, last_edit, active_flag, tax, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 170 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
289 290 291 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 289 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 283 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 |
# File 'lib/pipedrive-openapi-client/models/product_attachement_fields.rb', line 177 def valid? true end |