Class: Pipedrive::RecentsApi
- Inherits:
-
Object
- Object
- Pipedrive::RecentsApi
- Defined in:
- lib/pipedrive-openapi-client/api/recents_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RecentsApi
constructor
A new instance of RecentsApi.
-
#recents_get(since_timestamp, opts = {}) ⇒ nil
Get recents Returns data about all recent changes occured after given timestamp.
-
#recents_get_with_http_info(since_timestamp, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get recents Returns data about all recent changes occured after given timestamp.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RecentsApi
Returns a new instance of RecentsApi.
19 20 21 |
# File 'lib/pipedrive-openapi-client/api/recents_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pipedrive-openapi-client/api/recents_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#recents_get(since_timestamp, opts = {}) ⇒ nil
Get recents Returns data about all recent changes occured after given timestamp.
30 31 32 33 |
# File 'lib/pipedrive-openapi-client/api/recents_api.rb', line 30 def recents_get(, opts = {}) recents_get_with_http_info(, opts) nil end |
#recents_get_with_http_info(since_timestamp, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get recents Returns data about all recent changes occured after given timestamp.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pipedrive-openapi-client/api/recents_api.rb', line 43 def recents_get_with_http_info(, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RecentsApi.recents_get ...' end # verify the required parameter 'since_timestamp' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'since_timestamp' when calling RecentsApi.recents_get" end allowable_values = ["activity", "activityType", "deal", "delete_log", "file", "filter", "note", "person", "organization", "pipeline", "product", "stage", "user"] if @api_client.config.client_side_validation && opts[:'items'] && !allowable_values.include?(opts[:'items']) fail ArgumentError, "invalid value for \"items\", must be one of #{allowable_values}" end # resource path local_var_path = '/recents' # query parameters query_params = opts[:query_params] || {} query_params[:'since_timestamp'] = query_params[:'items'] = opts[:'items'] if !opts[:'items'].nil? query_params[:'start'] = opts[:'start'] if !opts[:'start'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['api_key', 'oauth2'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RecentsApi#recents_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |